# ===================================================================
# Configure the UI
# -----------------

init python:    
    #################################################################
    # Common styles
    # ---------------
    
    # buttons
    style.button.background = Frame("sys/button.png", 50, 50)
    style.button.hover_background = Frame("sys/button_hover.png", 50, 50)
    style.button.insensitive_background = Frame("sys/button_inactive.png", 50, 50)
    style.button.xpadding = 40
    style.button.ypadding = 8
    
    style.button_text.outlines = [ (1, "#0008") ]
    style.button_text.color = "#ccc"
    style.button_text.hover_color = "#fff"
    
    #dialog
    style.say_window.background = Frame("sys/window.png", 141, 141)
    style.say_window.left_padding = 10
    style.say_window.right_padding = 40
    style.say_window.top_padding = 5
    style.say_window.bottom_padding = 5
    style.say_window.xmargin = 8
    
    style.say_vbox.xfill = True
    style.say_vbox.box_spacing = 0
    
    style.say_who_window.background = "sys/who_window.png"
    style.say_who_window.left_padding = 55
    style.say_who_window.ypadding = 0
    style.say_who_window.ymargin = 0
    style.say_who_window.yminimum = 55
    style.say_who_window.xminimum = 280
    
    style.say_dialogue.outlines = [ (1, "#000a") ]
    style.say_dialogue['rollback'].color = "#ff6"
    style.say_dialogue.yoffset = -25
    style.say_thought.outlines  = [ (1, "#000a") ]
    style.say_thought['rollback'].color = "#ff6"
    style.say_thought.yoffset = -25
    
    style.centered_text.outlines = [ (2, "#0008"), (1, "#000a") ]
    style.centered_text['rollback'].color = "#ff6"
    
    style.centered_fast = Style(style.centered_text)
    style.centered_fast.slow_cps_multiplier = 3.5
    
    style.say_label.outlines = [ (1, "#000") ]
    style.say_label.bold = False
    style.say_label.yalign = .5
    style.say_label.yoffset = -2
    
    style.close_button = Style(style.image_button, help="Dialog close button")
    style.close_button.xalign = 1.0
    style.close_button.yoffset = -18
    style.close_button.xoffset = 47
    
    # ~ quick commands
    style.quick_command = Style(style.frame, help="Quick commands frame")
    style.quick_command.background = Frame("sys/quick_commands.png", 100, 25)
    style.quick_command.xpadding = 100
    style.quick_command.ypadding = 0
    style.quick_command.top_padding = 2
    style.quick_command.yminimum = 25
    style.quick_command.xfill = True
    style.quick_command.yalign = 1.0
    style.quick_command.yoffset = -12
    
    style.quick_command_hbox = Style(style.hbox, help="Quick commands hbox")
    style.quick_command_hbox.xalign = .5
    style.quick_command_hbox.yalign = .5
    
    # Yes/No Prompt
    style.yesno_frame.yalign = .5
    style.yesno_prompt_text.color = "#fff"
    style.yesno_prompt_text.outlines = [ (1, "#000a") ]
    
init -1 python hide:
    #################################################################
    # Common configurations
    # ----------------------
    
    config.thumbnail_width = 200
    config.thumbnail_height = 150
    config.has_quicksave = True

init -2 python:
    import os    
    import random, math
    
    os.environ['SDL_VIDEO_CENTERED'] = '1'
    
    # initialize random numbers
    random.seed()
    
    #################################################################
    # Snow particles
    # ----------------
    def Snow(image, max_particles, xspeed, yspeed, border_range):
        return Particles(SnowFactory(image, max_particles, xspeed, yspeed, border_range))
    
    class SnowFactory(object):
        def __init__(self, image, max_particles, xspeed, yspeed, border_range):
            self.alpha_factor = 50.0
            self.image = self.image_init(image)
            self.base = image
            self.max_particles = max_particles
            self.xspeed = xspeed
            self.yspeed = yspeed
            self.border_range = border_range

        def create(self, particles, st):
            
            if particles is None or len(particles) < self.max_particles:                
                return [ SnowParticle(self.image,
                                      self.xspeed,
                                      self.yspeed,
                                      random.randint(self.border_range[0], self.border_range[1]),
                                      random.uniform(25, 100),
                                      self) ]
        
        def image_init(self, image):
            rv = [ ]
            ystart = 0
            for index in range(10):
                cur = [ ]
                cur_image = im.Crop(image, index*20, 0, 20, 20)
                
                for alpha in range(int(self.alpha_factor)):
                    cur.append(im.Alpha(cur_image, alpha/self.alpha_factor))
                rv.append(cur)
                    
            return rv
        
        def flat(self, lista):
            flat = [ ]
            for image in lista:
                if isinstance(image, list):
                    flat.extend(self.flat(image))
                else:
                    flat.append(image)
            return flat
        
        def predict(self):
            flat = self.flat( self.image )
                
            return flat
            
    class SnowParticle(object):
        def __init__(self, image, xspeed, yspeed, border, life, parent):
            if yspeed <= 0:
                yspeed = 1
            
            life = life / 100.0
            self.xspeed = xspeed*life
            self.yspeed = yspeed*life
            self.border = border
            self.life = life
            self.offset = life*100.0
            self.oldst = None
            self.parent = parent
            self.wind = -1.5 * random.random()*3            
            
            offset = 10-math.floor(life*10.0)
            if offset < 0:
                offset = 0
            if offset > 9:
                offset = 9
            
            self.image = image[int(offset)]
            
            self.xpos = random.uniform(0, renpy.config.screen_width)
            self.ypos = -self.border
            
        def update(self, st):
            # calculate lag
            if self.oldst is None:
                self.oldst = st
            
            lag = st - self.oldst
            self.oldst = st
            
            # update position
            self.xpos += lag * self.xspeed + self.wind
            self.ypos += lag * self.yspeed
            
            # kills the particle slowly -wut
            self.life -= 0.08*lag
            
            frame = math.floor(self.life*self.parent.alpha_factor)
            if frame < 0:
                frame = 0
            if frame >= self.parent.alpha_factor-1:
                frame = self.parent.alpha_factor-1
                
            frame = self.image[int(frame)]
            
            if self.life < 0 or self.ypos > renpy.config.screen_height or\
               (self.xpos < -20 or self.xpos > renpy.config.screen_width):
                return None
                
            # returns the particle
            return int(self.xpos), int(self.ypos), self.offset, frame
            
        
    #################################################################
    # Main menu
    # -----------
    layout.provides('main_menu')
    
    # -------
    # Styles
    # ~
    # Button
    style.mm_button = Style(style.button, help="main menu button")
    style.mm_button.xanchor = 1.0
    style.mm_button.right_margin = 20
    
    # Button text
    style.mm_button_text = Style(style.button_text, help="main menu button (text)")
    style.mm_button.size_group = "mm"
    
    # Controls the main menu
    def screen_main_menu():
        while True:
            # background
            ui.image("sys/main_menu.jpg")
                        
            # snow particles
            ui.add(Snow("sys/snowflake.png", 30, 50, 200, (50, 600)))
            
            # logo
            ui.image("sys/logo.png", xpos=175, ypos=50)
            
            # buttons
            layout.button(u"New Game",
                          "mm",
                          clicked=ui.jumpsoutofcontext('start'),
                          xpos=800,
                          ypos=250)
                          
            layout.button(u"Continue",
                          "mm",
                          clicked=_intra_jumps("mm_load_screen", "main_game_transition"),
                          xpos=775,
                          ypos=300)
               
            clicked = None
            ##  if persistent.game_end:
                ##  clicked = _intra_jumps("mm_extras_screen", "main_game_transition")
                
            layout.button(u"Extras",
                          "mm",
                          clicked=clicked,
                          xpos=750,
                          ypos=350)
                          
            layout.button(u"Config",
                          "mm",
                          clicked=_intra_jumps("mm_preferences_screen", "main_game_transition"),
                          xpos=725,
                          ypos=400),
                          
            layout.button(u"Exit",
                          "mm",
                          clicked=ui.jumps("_quit"),
                          xpos=700,
                          ypos=450)
            
            ui.interact()
    
    #################################################################
    # In-Game Menu
    # -------------
    
    layout.provides("navigation")
    
    # -------
    # Styles
    # ~
    style.gm_nav_frame = Style(style.menu_frame, help="game menu navigation frame")
    style.gm_nav_box = Style(style.vbox, help="box containing game menu navigation buttons")

    style.gm_nav_button = Style(style.button, help="game menu navigation button")
    style.gm_nav_button_text = Style(style.button_text, help="game menu navigation button (text)")

    style.gm_nav_button.size_group = "gm_nav_button"
    
    style.gm_nav_frame.xalign = 1.0
    style.gm_nav_frame.ypos = 80
    style.gm_nav_frame.right_margin = 80
    style.gm_nav_frame.background = None
    
    def in_game_menu(screen=None):
        
        ui.add(Solid("#0008"))
        ui.image("sys/top.png")
        
        if screen is None:
            return
            
        if screen == "game_menu": 
            
            # buttons
            layout.button(u"Save",
                          "mm",
                          clicked=_intra_jumps("save_screen", "intra_transition"),
                          xpos=800,
                          ypos=150)
                          
            layout.button(u"Load",
                          "mm",
                          clicked=_intra_jumps("load_screen", "main_game_transition"),
                          xpos=775,
                          ypos=200)
                          
            layout.button(u"Config",
                          "mm",
                          clicked=_intra_jumps("preferences_screen", "intra_transition"),
                          xpos=750,
                          ypos=250)
                          
            layout.button(u"Title",
                          "mm",
                          clicked=ui.callsinnewcontext("_main_menu_prompt"),
                          xpos=725,
                          ypos=300),
                          
            layout.button(u"Exit",
                          "mm",
                          clicked=ui.callsinnewcontext("_quit_prompt"),
                          xpos=700,
                          ypos=350)
                          
            layout.button(u"Return",
                          "mm",
                          clicked=ui.jumps("_return"),
                          xpos=675,
                          ypos=400)
                          
        elif screen != "noreturn":
            layout.button(u"Return", "mm", clicked=ui.jumps("_return"), xpos=800, ypos=530)
                          
    layout.navigation = in_game_menu
    _game_menu_screen = "game_menu"
            
    
    #################################################################
    # Extras
    # -------
    
    def extras_screen():
        
        layout.navigation("extras")
        ui.image("sys/extras.png")
            
        buttons = [ ( "Gallery", _intra_jumps("gallery_screen", "intra_transition"), True ),
                    ( "Sound Mode", _intra_jumps("sound_screen", "intra_transition"), True ),
                    ( "Comments", _intra_jumps("_comments", "intra_transition"), True ) ]
            
        ui.vbox(spacing=5, xalign=1.0, yalign=.5)
        
        xoff = 0
        for button in buttons:
            button, action, enabled = button
            if not enabled:
                action = None
            
            layout.button(button, "mm", clicked=action, xoffset=xoff, xanchor=0)
            xoff -= 25
            
        ui.close()
            
    #################################################################
    # Load/Save screen
    # -----------------
    
    layout.provides('load_save')
    
    loadsave_cols = 2
    loadsave_rows = 2
    loadsave_max_pages = 10
    loadsave_empty_thumbnail = None
    loadsave_time_format = "%b %d, %H:%M"
    quick_slots = 1
    _load_prompt = True
    
    # -------
    # Styles
    # ~
    
    style.file_picker_window = Style(style.window)
    style.file_picker_window.xfill = False
    style.file_picker_window.yalign = .5
    style.file_picker_window.xalign = .5
    
    style.file_picker_grid = Style(style.default)
    style.file_picker_image = Style(style.default)
    style.file_picker_image.xalign = .5
    style.file_picker_image.foreground = Frame("sys/save_mask.png", 50, 50)
    style.file_picker_entry = Style(style.large_button)
    style.file_picker_entry.xpadding = 8
    style.file_picker_entry.ypadding = 8
    style.file_picker_entry['quick'].foreground = "sys/quick_save.png"
    style.file_picker_entry['auto'].foreground = "sys/auto_save.png"
    style.file_picker_entry.background = Frame("sys/slot.png", 100, 100)
    style.file_picker_entry.hover_background = Frame("sys/slot_hover.png", 100, 100)
    style.file_picker_entry.insensitive_background = Frame("sys/slot_insensitive.png", 100, 100)
    style.file_picker_text = Style(style.large_button_text)
    style.file_picker_text.xalign = .5
    style.file_picker_text.outlines = [ (1, "#000d") ]
    style.file_picker_empty_slot = Style(style.file_picker_text)
    style.file_picker_extra_info = Style(style.file_picker_text)
    style.file_picker_extra_info.size = 10
    style.file_picker_extra_info.color = "#fff"
    style.file_picker_extra_info.outlines = [ ]
    style.file_picker_time = Style(style.file_picker_text)
    style.file_picker_time.color = "#ffc"
    
    
    def _file_picker(screen, save):
        saved_games = renpy.list_saved_games(regexp=r'(quicksave)|((auto-)?[0-9]+)')
        
        save_info = { }
        
        for fn, extra_info, screenshot, gametime in saved_games:
            save_info[fn] = [extra_info, screenshot, gametime]
            
        
        page = 0
        
        while True:
            
            layout.navigation(screen)
            
            if save:
                ui.image("sys/save.png")
            else:
                ui.image("sys/load.png")
            
            ui.window(style="file_picker_window")
            
            # a vbox so we can show the pages
            ui.vbox()
            
            # a grid with all saves we have
            ui.grid(loadsave_cols, loadsave_rows, style="file_picker_grid")
            
            # Renders a slot
            def render_slot(filename, offset, read_only=False, type=""):
                
                clicked = None
                if not save or (save and not read_only):
                    clicked = ui.returns(("pick", filename))
                    
                if not filename in save_info:                    
                    extra_info = ""
                    screenshot = None
                    game_time = None
                    
                else:
                    extra_info, screenshot, game_time = save_info[filename]
                
                ui.button(style=style.file_picker_entry[type],
                          clicked = clicked)
                ui.vbox(style=style.file_picker_entry[type+str(offset)])
                
                # Screenshot
                if screenshot is None:
                    if loadsave_empty_thumbnail:
                        ui.add(loadsave_empty_thumbnail)
                    else:
                        ui.null(width=config.thumbnail_width, height=config.thumbnail_height)
                else:
                    ui.window(style='file_picker_image')
                    screenshot = im.Scale(screenshot, config.thumbnail_width, config.thumbnail_height)
                    ui.add(im.AlphaMask(screenshot, "sys/save_msk.png"))
                    
                
                ui.null(width=226, height=5)
                
                # Save information
                if not filename in save_info:
                    ui.text(_(u"- Empty Slot -"), style=style.file_picker_empty_slot[type+str(offset)])
                    ui.text(" ", style=style.file_picker_extra_info[type+str(offset)])
                else:
                    import time
                    
                    ui.text(time.strftime(loadsave_time_format, time.localtime(game_time)), style=style.file_picker_time[type+str(offset)])
                    ui.text(extra_info, style=style.file_picker_extra_info[type+str(offset)])
                                    
                ui.close() # vbox
                
            # get the files
            def page_files(page):
                
                rv = [ ]
                count = loadsave_cols * loadsave_rows
                
                if page == -1:
                    if config.has_quicksave:
                        for i in range(quick_slots):
                            rv.append(("quicksave", True, "quick"))
                        count -= quick_slots
                        
                    if config.has_autosave:
                        for i in range(count):
                            rv.append(("auto-" + str(i+1), True, "auto"))
                        count = 0
            
                else:
                    for i in range(count):
                        rv.append(("%d" % (i + (page*count)), False, ""))
                        
                return rv
            
            for i, (filename, force_save, type) in enumerate(page_files(page)):
                render_slot(filename, i, force_save, type)
                ##  ui.null()
                
            ui.close() # grid
            ui.close() # vbox
            
            if page > -1:
                ui.at(Move((100, .5, 0, .5), (80, .5, 0, .5), 1.0, repeat=True, bounce=True))
                ui.imagebutton("sys/arrow_left.png", "sys/arrow_lefth.png", clicked=ui.returns(("prev", 1)))
                               
            if page < loadsave_max_pages-1:
                ui.at(Move((700, .5, 1.0, .5), (720, .5, 1.0, .5), 1.0, repeat=True, bounce=True))
                ui.imagebutton("sys/arrow_right.png", "sys/arrow_righth.png", clicked=ui.returns(("next", 1)))
            
            cmd, value = ui.interact()
            
            if cmd == "pick":
                return value
                
            elif cmd == "prev":
                page -= value
                if page < -1:
                    page = -1
                    
            elif cmd == "next":
                page += value
                if page >= loadsave_max_pages:
                    page = loadsave_max_pages-1
    
    
    #################################################################
    # Extras screen
    # --------------
            
    #################################################################
    # Configure screen
    # -----------------
    
    layout.provides('preferences')
    
    # -------
    # Styles
    # ~
    style.prefs_vbox = Style(style.vbox)
    style.prefs_vbox.xalign = .5
    style.prefs_vbox.ypos = 200
    
    style.prefs_label = Style(style.button_text)
    style.prefs_label.color = "#fff"
    style.prefs_label.outlines = [ (1, "#000d") ]
    
    style.prefs_button = Style(style.radio_button, help="preference value button")
    style.prefs_button.background = "sys/radio_button.png"
    style.prefs_button.hover_background = "sys/radio_buttonh.png"
    style.prefs_button.selected_background = "sys/radio_button_check.png"
    style.prefs_button.selected_hover_background = "sys/radio_button_checkh.png"
    style.prefs_button.xpadding = 0
    style.prefs_button.ypadding = 0
    style.prefs_button.left_padding = 32
    style.prefs_button.size_group = "prefs"
    
    style.prefs_button_text = Style(style.radio_button_text, help="preference value button (text)")
    style.prefs_button_text.selected_color = "#fff"
    style.prefs_button_text.xalign = 0
    
    style.prefs_label = Style(style.label, help="a preference label (window)")
    style.prefs_label.xfill = False
    style.prefs_label.yalign = 1.0
    style.prefs_label.left_padding = 10
    
    style.prefs_label_text = Style(style.label_text, help="a preference label (text)")
    style.prefs_label_text.color = "#fff"
    style.prefs_label_text.outlines = [ (1, "#000d") ]
    
    style.prefs_slider = Style(style.slider, help="preference value slider bar")
    style.prefs_volume_slider = Style(style.prefs_slider, help="volume slider bar")    
    
    style.prefs_frame = Style(style.frame)
    style.prefs_frame.xmargin = 100
    style.prefs_frame.xalign = .5
    style.prefs_frame.yalign = .5
    
    pref_map = [
        { "label": u"Display",
          "choices": [ (u"Fullscreen", True), (u"Windowed", False)],
          "field": "fullscreen" },
        
        { "label": u"Visual Effects",
          "choices": [ (u"On", 2), (u"Off", 0)],
          "field": "transitions" },
              
        { "label": u"Skip Mode",
          "choices": [(u"Read", True), (u"All", False)],
          "field": "skip_unseen" },
        
        { "label": u"Text Speed",
          "range": 140, "type": "slider",
          "field": "text_cps" },
              
        { "label": u"Auto-read Speed",
          "range": 40, "type": "slider",
          "field": "afm_time" },
              
        { "label": u"Music Volume",
          "mixer": "music", "type": "volume" },
              
        { "label": u"Sound Volume",
          "mixer": "sfx", "type": "volume" }          
          
    ]
    
    _pref_height = 30
    
    def preferences_screen():
        while True:            
            
            layout.navigation("preferences")
            
            ui.image("sys/configure.png")
            
            ui.frame(style="prefs_frame")
            ui.hbox(spacing=10)
            
            ui.vbox(spacing=10)
            # draw labels...
            for pref in pref_map:
                ui.hbox()
                layout.label(pref["label"], "prefs")
                ui.null(height=_pref_height)
                ui.close() #hbox
                
            ui.null(width=250)
            ui.close() # vbox
            
            def get_key(dict, key, default):
                if dict.has_key(key):
                    return dict[key]
                else:
                    return default
            
            ui.vbox(spacing=10)
            for pref in pref_map:
                ui.hbox()
                type = get_key(pref, "type", "choice")
                base = get_key(pref, "base", _preferences)
                if type == "choice":
                    preferences_choice(pref["field"], pref["choices"])
                
                elif type == "slider":
                    preferences_slider(pref["label"], pref["field"], pref["range"])
                
                elif type == "volume":
                    preferences_volume(pref["mixer"], get_key(pref, "channel", 0))
                
                ui.null(height=_pref_height)
                ui.close() # hbox
                    
            ui.close() # vbox
            ui.close() # hbox
            
            ui.interact()
            
            
    def preferences_choice(field, choices, base=_preferences):
        ui.grid(len(choices), 1, 10, xfill=True)
        
        cur = getattr(base, field)
        
        for choice, value in choices:
            def clicked(value=value, base=base, field=field):
                setattr(base, field, value)
                return True
                
            layout.button(choice, "prefs", clicked=clicked, selected=(cur == value))
            
        ui.close() # grid
            
    def preferences_slider(label, field, range, base=_preferences):
        
        cur = getattr(base, field)
        
        if cur == 0:
            cur = range
        else:
            cur -= 1
            
        def changed(base, field, value):
            value += 1
            if value > range:
                value = 0
            
            setattr(base, field, value)
            
        
        ui.bar(range, cur, changed=renpy.curry(changed)(base, field), style=style.prefs_slider[label])
    
    def preferences_volume(mixer, channel=0):
        def changed(value):
            _preferences.set_volume(mixer, value / 128.0)
            
        ui.bar(128, int(_preferences.get_volume(mixer) * 128), changed=changed, style=style.prefs_volume_slider)
            
    layout.preferences = preferences_screen
    
    
    #################################################################
    # Dialog
    # -------
    
    # Shows the dialog with the close button -oh crap, why it have to be this way?-
    # Just a mod of renpy.show_display_say
    def custom_display_say(who, what, who_args={}, what_args={}, window_args={},
                     image=False, side_image=None, two_window=False,
                     two_window_vbox_properties={},
                     who_window_properties={},
                     say_vbox_properties={},
                     variant=None,
                     **kwargs):

        def handle_who():
            if who:
                if image:
                    ui.add(renpy.display.im.image(who, loose=True, **who_args))
                else:
                    ui.text(who, **who_args)

        def merge_style(style, properties):

            if isinstance(style, basestring):
                style = getattr(renpy.store.style, style)

            if variant is not None:
                style = style[variant]
                
            if renpy.exports.in_rollback():
                style = style["rollback"]
                
            rv = dict(style=style)
            rv.update(properties)
            return rv

        def style_args(d):

            if not "style" in d:
                return d

            in_rollback = renpy.exports.in_rollback()
            
            if (not in_rollback) and (not variant):
                return d
                
            d = d.copy()
            
            style = d["style"]

            if isinstance(style, basestring):
                style = getattr(renpy.store.style, style)        

                if variant is not None:
                    style = style[variant]

                if in_rollback:
                    style = style["rollback"]

            d["style"] = style

            return d
        
        who_args = style_args(who_args)
        what_args = style_args(what_args)
        window_args = style_args(window_args)
        
        if two_window:

            # Opens say_two_window_vbox.
            ui.vbox(**merge_style('say_two_window_vbox', two_window_vbox_properties))

            ui.window(**merge_style('say_who_window', who_window_properties))
            handle_who()

        ui.window(**window_args)                    
                    
        # Opens the say_vbox.
        ui.vbox(**merge_style('say_vbox', say_vbox_properties))
        ui.imagebutton("sys/close_button.png", "sys/close_buttonh.png", 
            clicked=ui.callsinnewcontext("_hide_windows"), style='close_button')

        if not two_window:
            handle_who()

        rv = ui.text(what, **what_args)

        # Closes the say_vbox.
        ui.close()

        if two_window:
            # Closes the say_two_window_vbox.
            ui.close()

        if side_image:
            ui.image(side_image)
            
        quick_commands()
        
        return rv
        
    
    _afm_time = _preferences.afm_time or 10
    
    # Reading utils
    def toggle_skipping():
        config.skipping = not config.skipping
        renpy.restart_interaction() # to make sure button is updated ^^
        
    def toggle_autoread():
        global _afm_time
        
        if _preferences.afm_time > 0:
            _afm_time = _preferences.afm_time
            _preferences.afm_time = 0
        else:
            _preferences.afm_time = _afm_time
            
        renpy.restart_interaction() # to make sure button is updated ^^
        
    
    def quick_commands():
        # to save typing
        ccinc = ui.callsinnewcontext

        skip_role = ""
        if config.skipping:
            skip_role = "selected_"
            
        auto_role = ""
        if _preferences.afm_time > 0:
            auto_role = "selected_"

        # buttons
        ui.frame(style='quick_command')
        ui.hbox(style='quick_command_hbox', spacing=5)
        
        # quick save/load
        ui.imagebutton("sys/quick/quick_save.png", "sys/quick/quick_save_h.png", clicked=ccinc("quick_save"))
        ui.imagebutton("sys/quick/quick_load.png", "sys/quick/quick_load_h.png", 
                       clicked=(ccinc("quick_load") if renpy.can_load("quicksave") else None))
        
        ui.null(width=50)
        
        # reading functions
        ui.imagebutton("sys/quick/back.png", "sys/quick/back_h.png", clicked=renpy.rollback)
        ui.imagebutton("sys/quick/auto.png", "sys/quick/auto_h.png", clicked=toggle_autoread,
                    selected_idle_image="sys/quick/auto_h.png", role=auto_role)
        ui.imagebutton("sys/quick/skip.png", "sys/quick/skip_h.png", clicked=toggle_skipping,
                    selected_idle_image="sys/quick/skip_h.png", role=skip_role)
        
        ui.null(width=50)
        
        # system functions
        ui.imagebutton("sys/quick/load.png", "sys/quick/load_h.png", clicked=ccinc("_game_menu_load"))
        ui.imagebutton("sys/quick/save.png", "sys/quick/save_h.png", clicked=ccinc("_game_menu_save"))
        ui.imagebutton("sys/quick/config.png", "sys/quick/config_h.png", clicked=ccinc("_game_menu_preferences"))
        
        ui.close() # ui.hbox()
    
init python:
    sp_menu = True
    
label main_menu_screen:
    if sp_menu:
        scene expression "sys/main_menu.jpg"
        show expression Alpha(0, 1.0, 1.5)("sys/logo.png") at Move((175, 15), (175, 50), .75)
        with Pause(.5)
        python:
            _buttons = [u"New Game", u"Continue", u"Extras", u"Config", u"Exit"]
            xpos = 800
            ypos = 250
            delay = .5
            for button in _buttons:
                ui.at(Move((800+(800-xpos), ypos, 1.0, 0), (xpos, ypos, 1.0, 0), delay))
                ui.add(Alpha(0, 1.0, delay)( Button(Text(button, style="mm_button_text"), style="mm_button")))
                xpos -= 25
                ypos += 50
                delay += .1
            
        with Pause(1.0)
        $ sp_menu = False
        $ renpy.transition(dissolve)
        
    $ screen_main_menu()
    
    
label game_menu:
    python hide:
        while True:
            layout.navigation('game_menu')
            ui.interact()
            
            
label preferences_screen:
    python hide:
        preferences_screen()
    
    jump preferences_screen
    
    
label save_screen:
    python hide:
        while True:
            fn = _file_picker("save", True)

            if renpy.can_load(fn):
                if not layout.yesno_prompt("save", u"Are you sure you want to overwrite your save?"):
                    continue

            renpy.save(fn, extra_info=store.save_name)


label load_screen:
    python hide:
        while True:
            fn = _file_picker("load", False)
            
            if _load_prompt:
                if not layout.yesno_prompt("load",  u"Loading will lose unsaved progress.\nAre you sure you want to do this?"):
                    continue

            renpy.load(fn)
            
            
label quick_save:    
    python hide:        
        renpy.take_screenshot()
                
        if renpy.can_load("quicksave"):
            if not layout.yesno_prompt("noreturn", "Overwrite quickslot save?"):                     
                return
                
        renpy.save("quicksave", extra_info=store.save_name)
        
        # game saved =D
        renpy.with_statement(dissolve)
        layout.navigation()
        ui.text(u"- Game saved -", xalign=.5, yalign=.5, size=28, outlines=[ (1, "#000d") ])
        ui.saybehavior()
        ui.interact(suppress_overlay=True, suppress_underlay=True)
        
    return
        
        
label quick_load:
    python hide:
        if renpy.can_load("quicksave"):
            if layout.yesno_prompt("noreturn",  u"Loading will lose unsaved progress.\nAre you sure you want to do this?"):
                renpy.load("quicksave")
        
    return

label extras_screen:
    python hide:
        while True:
            extras_screen()
            ui.interact()
    
## Geez, we want this to have the same background as menu =D
label mm_load_screen:
    scene expression "sys/main_menu.jpg"
    jump load_screen
    
label mm_extras_screen:
    scene expression "sys/main_menu.jpg"
    jump extras_screen
    
label mm_preferences_screen:
    scene expression "sys/main_menu.jpg"
    jump preferences_screen
        